==> pmml-model-1.0.0-sources.jar: org/dmg/pmml/BaseCumHazardTables.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;choice>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}BaselineStratum" maxOccurs="unbounded"/>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}BaselineCell" maxOccurs="unbounded"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *       &lt;attribute name="maxTime" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "baselineStrata",
    "baselineCells"
})
@XmlRootElement(name = "BaseCumHazardTables")
@Schema(min = Version.PMML_4_0)
public class BaseCumHazardTables
    extends PMMLObject
    implements Equals, HashCode
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "BaselineStratum")
    protected List<BaselineStratum> baselineStrata;
    @XmlElement(name = "BaselineCell")
    protected List<BaselineCell> baselineCells;
    @XmlAttribute(name = "maxTime")
    protected Double maxTime;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the baselineStrata property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the baselineStrata property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getBaselineStrata().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link BaselineStratum }
     * 
     * 
     */
    public List<BaselineStratum> getBaselineStrata() {
        if (baselineStrata == null) {
            baselineStrata = new ArrayList<BaselineStratum>();
        }
        return this.baselineStrata;
    }

    /**
     * Gets the value of the baselineCells property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the baselineCells property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getBaselineCells().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link BaselineCell }
     * 
     * 
     */
    public List<BaselineCell> getBaselineCells() {
        if (baselineCells == null) {
            baselineCells = new ArrayList<BaselineCell>();
        }
        return this.baselineCells;
    }

    /**
     * Gets the value of the maxTime property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getMaxTime() {
        return maxTime;
    }

    /**
     * Sets the value of the maxTime property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setMaxTime(Double value) {
        this.maxTime = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof BaseCumHazardTables)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final BaseCumHazardTables that = ((BaseCumHazardTables) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            List<BaselineStratum> lhsBaselineStrata;
            lhsBaselineStrata = (((this.baselineStrata!= null)&&(!this.baselineStrata.isEmpty()))?this.getBaselineStrata():null);
            List<BaselineStratum> rhsBaselineStrata;
            rhsBaselineStrata = (((that.baselineStrata!= null)&&(!that.baselineStrata.isEmpty()))?that.getBaselineStrata():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "baselineStrata", lhsBaselineStrata), LocatorUtils.property(thatLocator, "baselineStrata", rhsBaselineStrata), lhsBaselineStrata, rhsBaselineStrata)) {
                return false;
            }
        }
        {
            List<BaselineCell> lhsBaselineCells;
            lhsBaselineCells = (((this.baselineCells!= null)&&(!this.baselineCells.isEmpty()))?this.getBaselineCells():null);
            List<BaselineCell> rhsBaselineCells;
            rhsBaselineCells = (((that.baselineCells!= null)&&(!that.baselineCells.isEmpty()))?that.getBaselineCells():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "baselineCells", lhsBaselineCells), LocatorUtils.property(thatLocator, "baselineCells", rhsBaselineCells), lhsBaselineCells, rhsBaselineCells)) {
                return false;
            }
        }
        {
            Double lhsMaxTime;
            lhsMaxTime = this.getMaxTime();
            Double rhsMaxTime;
            rhsMaxTime = that.getMaxTime();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "maxTime", lhsMaxTime), LocatorUtils.property(thatLocator, "maxTime", rhsMaxTime), lhsMaxTime, rhsMaxTime)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            List<BaselineStratum> theBaselineStrata;
            theBaselineStrata = (((this.baselineStrata!= null)&&(!this.baselineStrata.isEmpty()))?this.getBaselineStrata():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "baselineStrata", theBaselineStrata), currentHashCode, theBaselineStrata);
        }
        {
            List<BaselineCell> theBaselineCells;
            theBaselineCells = (((this.baselineCells!= null)&&(!this.baselineCells.isEmpty()))?this.getBaselineCells():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "baselineCells", theBaselineCells), currentHashCode, theBaselineCells);
        }
        {
            Double theMaxTime;
            theMaxTime = this.getMaxTime();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "maxTime", theMaxTime), currentHashCode, theMaxTime);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

}

==> pmml-model-1.0.5-sources.jar: org/dmg/pmml/BaseCumHazardTables.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;choice>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}BaselineStratum" maxOccurs="unbounded"/>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}BaselineCell" maxOccurs="unbounded"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *       &lt;attribute name="maxTime" type="{http://www.dmg.org/PMML-4_1}REAL-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "baselineStrata",
    "baselineCells"
})
@XmlRootElement(name = "BaseCumHazardTables")
@Schema(min = Version.PMML_4_0)
public class BaseCumHazardTables
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "BaselineStratum")
    protected List<BaselineStratum> baselineStrata;
    @XmlElement(name = "BaselineCell")
    protected List<BaselineCell> baselineCells;
    @XmlAttribute(name = "maxTime")
    protected Double maxTime;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the baselineStrata property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the baselineStrata property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getBaselineStrata().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link BaselineStratum }
     * 
     * 
     */
    public List<BaselineStratum> getBaselineStrata() {
        if (baselineStrata == null) {
            baselineStrata = new ArrayList<BaselineStratum>();
        }
        return this.baselineStrata;
    }

    /**
     * Gets the value of the baselineCells property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the baselineCells property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getBaselineCells().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link BaselineCell }
     * 
     * 
     */
    public List<BaselineCell> getBaselineCells() {
        if (baselineCells == null) {
            baselineCells = new ArrayList<BaselineCell>();
        }
        return this.baselineCells;
    }

    /**
     * Gets the value of the maxTime property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getMaxTime() {
        return maxTime;
    }

    /**
     * Sets the value of the maxTime property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setMaxTime(Double value) {
        this.maxTime = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof BaseCumHazardTables)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final BaseCumHazardTables that = ((BaseCumHazardTables) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            List<BaselineStratum> lhsBaselineStrata;
            lhsBaselineStrata = (((this.baselineStrata!= null)&&(!this.baselineStrata.isEmpty()))?this.getBaselineStrata():null);
            List<BaselineStratum> rhsBaselineStrata;
            rhsBaselineStrata = (((that.baselineStrata!= null)&&(!that.baselineStrata.isEmpty()))?that.getBaselineStrata():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "baselineStrata", lhsBaselineStrata), LocatorUtils.property(thatLocator, "baselineStrata", rhsBaselineStrata), lhsBaselineStrata, rhsBaselineStrata)) {
                return false;
            }
        }
        {
            List<BaselineCell> lhsBaselineCells;
            lhsBaselineCells = (((this.baselineCells!= null)&&(!this.baselineCells.isEmpty()))?this.getBaselineCells():null);
            List<BaselineCell> rhsBaselineCells;
            rhsBaselineCells = (((that.baselineCells!= null)&&(!that.baselineCells.isEmpty()))?that.getBaselineCells():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "baselineCells", lhsBaselineCells), LocatorUtils.property(thatLocator, "baselineCells", rhsBaselineCells), lhsBaselineCells, rhsBaselineCells)) {
                return false;
            }
        }
        {
            Double lhsMaxTime;
            lhsMaxTime = this.getMaxTime();
            Double rhsMaxTime;
            rhsMaxTime = that.getMaxTime();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "maxTime", lhsMaxTime), LocatorUtils.property(thatLocator, "maxTime", rhsMaxTime), lhsMaxTime, rhsMaxTime)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            List<BaselineStratum> theBaselineStrata;
            theBaselineStrata = (((this.baselineStrata!= null)&&(!this.baselineStrata.isEmpty()))?this.getBaselineStrata():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "baselineStrata", theBaselineStrata), currentHashCode, theBaselineStrata);
        }
        {
            List<BaselineCell> theBaselineCells;
            theBaselineCells = (((this.baselineCells!= null)&&(!this.baselineCells.isEmpty()))?this.getBaselineCells():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "baselineCells", theBaselineCells), currentHashCode, theBaselineCells);
        }
        {
            Double theMaxTime;
            theMaxTime = this.getMaxTime();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "maxTime", theMaxTime), currentHashCode, theMaxTime);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            List<BaselineStratum> theBaselineStrata;
            theBaselineStrata = (((this.baselineStrata!= null)&&(!this.baselineStrata.isEmpty()))?this.getBaselineStrata():null);
            strategy.appendField(locator, this, "baselineStrata", buffer, theBaselineStrata);
        }
        {
            List<BaselineCell> theBaselineCells;
            theBaselineCells = (((this.baselineCells!= null)&&(!this.baselineCells.isEmpty()))?this.getBaselineCells():null);
            strategy.appendField(locator, this, "baselineCells", buffer, theBaselineCells);
        }
        {
            Double theMaxTime;
            theMaxTime = this.getMaxTime();
            strategy.appendField(locator, this, "maxTime", buffer, theMaxTime);
        }
        return buffer;
    }

}
